@@ -1,4 +1,4 @@
-/* $Id: nano.c,v 1.144.2.18 2001/10/28 14:52:45 astyanax Exp $ */
+/* $Id: nano.c,v 1.144.2.21 2001/12/14 05:57:10 astyanax Exp $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -1314,8 +1314,10 @@ int do_int_spell_fix(char *word)
 
 	search_last_line = FALSE;
 
-	j = i;
-	do_replace_loop(prevanswer, fileage, &beginx_top, TRUE, &j);
+	if (strcmp(prevanswer,answer) != 0) {
+	   j = i;
+	   do_replace_loop(prevanswer, fileage, &beginx_top, TRUE, &j);
+	}
     }
 
     /* restore the search/replace strings */
@@ -1696,6 +1698,9 @@ RETSIGTYPE do_cont(int signal)
 	SIGTSTP handler */
 
     doupdate();
+    /* The Hurd seems to need this, otherwise a ^Y after a ^Z will
+	start suspending again */
+   signal_init();
 }
 
 void handle_sigwinch(int s)
@@ -1790,13 +1795,21 @@ void signal_init(void)
     act.sa_handler = handle_sigwinch;
     sigaction(SIGWINCH, &act, NULL);
 
+
+#ifdef _POSIX_VDISABLE
+    tcgetattr(0, &term);
+
+#ifdef VDSUSP
+    term.c_cc[VDSUSP] = _POSIX_VDISABLE;
+#endif /* VDSUSP */
+
+#endif /* _POSIX_VDISABLE */
+
     if (!ISSET(SUSPEND)) {
 
 /* Insane! */
 #ifdef _POSIX_VDISABLE
-	tcgetattr(0, &term);
 	term.c_cc[VSUSP] = _POSIX_VDISABLE;
-	tcsetattr(0, TCSANOW, &term);
 #else
 	act.sa_handler = SIG_IGN;
 	sigaction(SIGTSTP, &act, NULL);
@@ -1814,6 +1827,12 @@ void signal_init(void)
 	sigaction(SIGCONT, &act, NULL);
     }
 
+
+#ifdef _POSIX_VDISABLE
+    tcsetattr(0, TCSANOW, &term);
+#endif
+
+
 }
 
 void window_init(void)
@@ -2613,6 +2632,7 @@ int main(int argc, char *argv[])
 		    kbinput = KEY_PPAGE;
 		    wgetch(edit);
 		    break;
+		case 'V':	/* Alt-[-V = Page Up in Hurd Console */
 		case 'I':	/* Alt-[-I = Page Up - FreeBSD Console */
 		    kbinput = KEY_PPAGE;
 		    break;
@@ -2620,6 +2640,7 @@ int main(int argc, char *argv[])
 		    kbinput = KEY_NPAGE;
 		    wgetch(edit);
 		    break;
+		case 'U':	/* Alt-[-U = Page Down in Hurd Console */
 		case 'G':	/* Alt-[-G = Page Down - FreeBSD Console */
 		    kbinput = KEY_NPAGE;
 		    break;
@@ -2631,6 +2652,10 @@ int main(int argc, char *argv[])
 		    kbinput = KEY_END;
 		    wgetch(edit);
 		    break;
+		case '9':	/* Alt-[-9 = Delete in Hurd Console */
+		    kbinput = KEY_DC;
+		    break;
+		case '@':	/* Alt-[-9 = Insert in Hurd Console */
 		case 'L':		/* Insert Key - FreeBSD Console */
 		    do_insertfile();
 		    keyhandled = 1;
@@ -2654,6 +2679,7 @@ int main(int argc, char *argv[])
 		    kbinput = KEY_HOME;
 		    break;
 		case 'F':
+		case 'Y':		/* End Key in Hurd Console */
 		    kbinput = KEY_END;
 		    break;
 		default:
